@@ -727,6 +727,40 @@ def edges_to_coo(edges, count=None, data=None):
     return matrix
 
 
+def neighbors(edges, max_index=None, directed=False):
+    """
+    Find the neighbors for each node in an edgelist graph.
+
+    TODO : re-write this with sparse matrix operations
+
+    Parameters
+    ------------
+    edges : (n, 2) int
+      Connected nodes
+    directed : bool
+      If True, only connect edges in one direction
+
+    Returns
+    ---------
+    neighbors : sequence
+      Vertex index corresponds to set of other vertex indices
+    """
+    neighbors = collections.defaultdict(set)
+    if directed:
+        [neighbors[edge[0]].add(edge[1])
+         for edge in edges]
+    else:
+        [(neighbors[edge[0]].add(edge[1]),
+          neighbors[edge[1]].add(edge[0]))
+         for edge in edges]
+
+    if max_index is None:
+        max_index = edges.max() + 1
+    array = [list(neighbors[i]) for i in range(max_index)]
+
+    return array
+
+
 def smoothed(mesh, angle=None, facet_minarea=15):
     """
     Return a non- watertight version of the mesh which
