@@ -234,6 +234,12 @@ class Scene(Geometry):
           MD5 hash of scene
         """
         # start with transforms hash
+        return util.md5_object(self._hashable())
+
+    def crc(self):
+        return caching.crc32(self._hashable())
+
+    def _hashable(self):
         hashes = [self.graph.md5()]
         for g in self.geometry.values():
             if hasattr(g, 'md5'):
@@ -244,10 +250,8 @@ class Scene(Geometry):
                 # try to just straight up hash
                 # this may raise errors
                 hashes.append(str(hash(g)))
-
-        md5 = util.md5_object(''.join(hashes))
-
-        return md5
+        hashable = ''.join(sorted(hashes)).encode('utf-8')
+        return hashable
 
     @property
     def is_empty(self):
@@ -645,7 +649,7 @@ class Scene(Geometry):
           Camera object defined for the scene
         """
         # no camera set for the scene yet
-        if not hasattr(self, '_camera') or self._camera is None:
+        if not self.has_camera:
             # will create a camera with everything in view
             return self.set_camera()
         assert self._camera is not None
@@ -666,6 +670,10 @@ class Scene(Geometry):
             return
         self._camera = camera
 
+    @property
+    def has_camera(self):
+        return hasattr(self, '_camera') and self._camera is not None
+
     @property
     def lights(self):
         """
@@ -995,7 +1003,7 @@ class Scene(Geometry):
         scale_3D = np.eye(4) * scale
 
         # preallocate transforms and geometries
-        nodes = self.graph.nodes_geometry
+        nodes = np.array(self.graph.nodes_geometry)
         transforms = np.zeros((len(nodes), 4, 4))
         geometries = [None] * len(nodes)
 
@@ -1023,7 +1031,7 @@ class Scene(Geometry):
                 # otherwise apply the full transform
                 result.geometry[geometry].apply_transform(new_geom)
 
-            for node, T in zip(self.graph.nodes_geometry[group],
+            for node, T in zip(nodes[group],
                                transforms[group]):
                 # generate the new transforms
                 transform = util.multi_dot(
